@@ -1,16 +1,11 @@
 ExtendHIT <-
 extend <-
 function (hit = NULL, hit.type = NULL, add.assignments = NULL, 
-    add.seconds = NULL, unique.request.token = NULL, keypair = credentials(), 
-    print = getOption('MTurkR.print'), browser = getOption('MTurkR.browser'),
-    log.requests = getOption('MTurkR.log'), sandbox = getOption('MTurkR.sandbox'),
-	validation.test = getOption('MTurkR.test')) {
-    if(!is.null(keypair)) {
-        keyid <- keypair[1]
-        secret <- keypair[2]
-    }
-    else
-        stop("No keypair provided or 'credentials' object not stored")
+    add.seconds = NULL, unique.request.token = NULL,
+    verbose = getOption('MTurkR.verbose'), ...) {
+    # temporary check for `print` argument (remove after v1.0)
+    if('print' %in% names(list(...)) && is.null(verbose))
+        verbose <- list(...)$print
     operation <- "ExtendHIT"
     GETparameters <- ""
     if(is.null(add.assignments) & is.null(add.seconds)) 
@@ -21,7 +16,7 @@ function (hit = NULL, hit.type = NULL, add.assignments = NULL,
         else if(as.numeric(add.assignments) < 1 | as.numeric(add.assignments) > 1e+09) 
             stop("Assignment increment must be between 1 and 1000000000")
         else GETparameters <- paste(GETparameters, "&MaxAssignmentsIncrement=", 
-									add.assignments, sep = "")
+                                    add.assignments, sep = "")
     }
     else if(!is.null(add.seconds)) {
         if(!is.numeric(add.seconds) & !is.numeric(as.numeric(add.seconds))) 
@@ -30,7 +25,7 @@ function (hit = NULL, hit.type = NULL, add.assignments = NULL,
             stop("Expiration increment must be between 3600 and 31536000")
         else
             GETparameters <- paste(GETparameters,"&ExpirationIncrementInSeconds=",
-									add.seconds, sep = "")
+                                    add.seconds, sep = "")
     }
     if(is.null(add.assignments)) 
         add.assignments <- 0
@@ -51,8 +46,7 @@ function (hit = NULL, hit.type = NULL, add.assignments = NULL,
     else if(!is.null(hit.type)) {
         if(is.factor(hit.type))
             hit.type <- as.character(hit.type)
-        hitsearch <- SearchHITs(keypair = keypair, print = FALSE, 
-            log.requests = log.requests, sandbox = sandbox, return.qual.dataframe = FALSE)
+        hitsearch <- SearchHITs(verbose = FALSE, return.qual.dataframe = FALSE, ...)
         hitlist <- hitsearch$HITs$HITId[hitsearch$HITs$HITTypeId %in% hit.type]
         if(length(hitlist) == 0 || is.null(hitlist))
             stop("No HITs found for HITType")
@@ -61,36 +55,24 @@ function (hit = NULL, hit.type = NULL, add.assignments = NULL,
                 c("HITId", "AssignmentsIncrement", "ExpirationIncrement", "Valid"))
     for(i in 1:length(hitlist)) {
         GETiteration <- paste(GETparameters, "&HITId=", hitlist[i], sep = "")
-        auth <- authenticate(operation, secret)
-        if(browser == TRUE) {
-            request <- request(keyid, auth$operation, auth$signature, 
-                auth$timestamp, GETiteration, browser = browser, 
-                sandbox = sandbox, validation.test = validation.test)
-			if(validation.test)
-				invisible(request)
+        request <- request(operation, GETparameters = GETiteration, ...)
+        if(is.null(request$valid))
+            return(request)
+        HITs[i, ] <- c(hitlist[i], add.assignments, add.seconds, request$valid)
+        if(request$valid == TRUE & print == TRUE) {
+            if(!is.null(add.assignments) & !is.null(add.seconds)) 
+                message(i, ": HIT (", hitlist[i], ") Extended by ", 
+                        add.assignments, " Assignments & ", add.seconds, " Seconds")
+            else if(!is.null(add.assignments)) 
+                message(i, ": HIT (", hitlist[i], ") Extended by ", 
+                        add.assignments, " Assignments")
+            else if(!is.null(add.seconds)) 
+                message(i, ": HIT (", hitlist[i], ") Extended by ", 
+                        add.seconds, " Seconds")
         }
-        else {
-            request <- request(keyid, auth$operation, auth$signature, 
-                auth$timestamp, GETiteration, log.requests = log.requests, 
-                sandbox = sandbox, validation.test = validation.test)
-			if(validation.test)
-				invisible(request)
-            HITs[i, ] = c(hitlist[i], add.assignments, add.seconds, request$valid)
-            if(request$valid == TRUE & print == TRUE) {
-                if(!is.null(add.assignments) & !is.null(add.seconds)) 
-					message(i, ": HIT (", hitlist[i], ") Extended by ", 
-							add.assignments, " Assignments & ", add.seconds, " Seconds")
-                else if(!is.null(add.assignments)) 
-					message(i, ": HIT (", hitlist[i], ") Extended by ", 
-							add.assignments, " Assignments")
-                else if(!is.null(add.seconds)) 
-					message(i, ": HIT (", hitlist[i], ") Extended by ", 
-							add.seconds, " Seconds")
-            }
-            else if(request$valid == FALSE & print == TRUE) {
-                warning(i, ": Invalid Request for HIT ", hitlist[i])
-            }
+        else if(request$valid == FALSE & print == TRUE) {
+            warning(i, ": Invalid Request for HIT ", hitlist[i])
         }
     }
-    invisible(HITs)
+    return(HITs)
 }
