@@ -2,15 +2,10 @@ GetReviewableHITs <-
 reviewable <-
 function (hit.type = NULL, status = NULL, response.group = "Minimal", 
     return.all = TRUE, pagenumber = "1", pagesize = "10", sortproperty = "Enumeration", 
-    sortdirection = "Ascending", keypair = credentials(), print = getOption('MTurkR.print'), 
-    log.requests = getOption('MTurkR.log'), sandbox = getOption('MTurkR.sandbox'),
-    validation.test = getOption('MTurkR.test')) {
-    if(!is.null(keypair)) {
-        keyid <- keypair[1]
-        secret <- keypair[2]
-    }
-    else
-        stop("No keypair provided or 'credentials' object not stored")
+    sortdirection = "Ascending", verbose = getOption('MTurkR.verbose'), ...) {
+    # temporary check for `print` argument (remove after v1.0)
+    if('print' %in% names(list(...)) && is.null(verbose))
+        verbose <- list(...)$print
     operation <- "GetReviewableHITs"
     if(!sortproperty %in% c("Title", "Reward", "Expiration", 
         "CreationTime", "Enumeration")) 
@@ -33,7 +28,7 @@ function (hit.type = NULL, status = NULL, response.group = "Minimal",
     }
     if(is.factor(hit.type))
         hit.type <- as.character(hit.type)
-    batch <- function(operation, pagenumber, pagesize) {
+    batch <- function(pagenumber, pagesize) {
         GETparameters <- paste("&PageNumber=", pagenumber, "&PageSize=", 
             pagesize, "&SortProperty=", sortproperty, "&SortDirection=", 
             sortdirection, sep = "")
@@ -41,12 +36,9 @@ function (hit.type = NULL, status = NULL, response.group = "Minimal",
             GETparameters <- paste(GETparameters, "&HITTypeId=", hit.type, sep = "")
         if(!is.null(status) && (status %in% c("Reviewable", "Reviewing"))) 
             GETparameters <- paste(GETparameters, "&Status=", status, sep = "")
-        auth <- authenticate(operation, secret)
-        batch <- request(keyid, auth$operation, auth$signature, 
-			auth$timestamp, GETparameters, log.requests = log.requests, 
-			sandbox = sandbox, validation.test = validation.test)
-		if(validation.test)
-			invisible(batch)
+        batch <- request(operation, GETparameters = GETparameters, ...)
+        if(is.null(batch$valid))
+            return(batch)
         batch$HITs <- NA
         batch$total <- as.numeric(strsplit(strsplit(batch$xml, 
             "<TotalNumResults>")[[1]][2], "</TotalNumResults>")[[1]][1])
@@ -59,15 +51,15 @@ function (hit.type = NULL, status = NULL, response.group = "Minimal",
         }
         return(batch)
     }
-    request <- batch(operation, pagenumber, pagesize)
-    if(validation.test)
-        invisible(request)
+    request <- batch(pagenumber, pagesize)
+    if(is.null(request$valid))
+        return(request)
     runningtotal <- request$batch.total
     pagenumber <- 2
     while(request$total > runningtotal) {
-        nextbatch <- batch(operation, pagenumber, pagesize)
-        if(validation.test)
-            invisible(nextbatch)
+        nextbatch <- batch(pagenumber, pagesize)
+        if(is.null(nextbatch$valid))
+            return(nextbatch)
         request$request.id <- c(request$request.id, nextbatch$request.id)
         request$valid <- c(request$valid, nextbatch$valid)
         request$xml.response <- c(request$xml, nextbatch$xml)
@@ -77,7 +69,7 @@ function (hit.type = NULL, status = NULL, response.group = "Minimal",
         pagenumber <- pagenumber + 1
     }
     request$batch.total <- NULL
-    if(print == TRUE) 
+    if(verbose) 
         message(request$total, " HITs Retrieved")
-    invisible(data.frame(HITId = request$HITs))
+    return(data.frame(HITId = request$HITs))
 }
