@@ -1,13 +1,10 @@
 HITStatus <-
 status <-
-function (hit = NULL, hit.type = NULL, keypair = credentials(), 
-    print = getOption('MTurkR.print'), log.requests = getOption('MTurkR.log'),
-    sandbox = getOption('MTurkR.sandbox')){
-    if((is.null(hit) & is.null(hit.type)) | (!is.null(hit) & !is.null(hit.type))) 
-        stop("Must provide 'hit' xor 'hit.type'")
-    hitsearch <- SearchHITs(keypair = keypair, print = TRUE, 
-                            log.requests = log.requests, sandbox = sandbox,
-                            return.qual.dataframe = FALSE)
+function (hit = NULL, hit.type = NULL, verbose = getOption('MTurkR.verbose'), ...){
+    # temporary check for `print` argument (remove after v1.0)
+    if('print' %in% names(list(...)) && is.null(verbose))
+        verbose <- list(...)$print
+    hitsearch <- SearchHITs(verbose = TRUE, return.qual.dataframe = FALSE, ...)
     HITs <- hitsearch$HITs
     if(is.null(HITs))
         return(HITs) # return if NULL
@@ -21,19 +18,20 @@ function (hit = NULL, hit.type = NULL, keypair = credentials(),
         names(toprint) <- c("HITId", "Review Status", "Assignments Pending", 
                             "Assignments Available", "Assignments Completed",
                             "Expiration")
-    }
-    else if(!is.null(hit.type)) {
-        if(is.factor(hit.type))
-            hit <- as.character(hit.type)
-        HITs <- HITs[HITs$HITTypeId %in% hit.type, ]
-        if(dim(HITs)[1] == 0) {
-            message("No HITs found for HITType")
-            invisible(HITs)
+    } else {
+        if(!is.null(hit.type)) {
+            if(is.factor(hit.type))
+                hit <- as.character(hit.type)
+            HITs <- HITs[HITs$HITTypeId %in% hit.type, ]
         }
-        if(dim(HITs)[1] > 1) {
-            toprint <- HITs[,c( "HITId","HITReviewStatus","NumberOfAssignmentsPending",
+        if(dim(HITs)[1] == 0) {
+            message("No HITs found!")
+            return(invisible(NULL))
+        }
+        toprint <- HITs[,c( "HITId","HITReviewStatus","NumberOfAssignmentsPending",
                                 "NumberOfAssignmentsAvailable",
                                 "NumberOfAssignmentsCompleted", "Expiration")]
+        if(dim(HITs)[1] > 1) {
             totals <- data.frame(HITId = c( "------------------------------", "Totals"),
                                 HITReviewStatus = c("---------------",""),
                                 NumberOfAssignmentsPending = c("--------------------",
@@ -46,9 +44,6 @@ function (hit = NULL, hit.type = NULL, keypair = credentials(),
             toprint <- rbind(toprint,totals)
         }
     }
-    if(print == TRUE){
-        print(toprint, row.names = FALSE)
-        message()
-    }
-    invisible(HITs)
+    print(toprint, row.names = FALSE)
+    return(invisible(HITs))
 }
