@@ -1,8 +1,5 @@
 RequesterReport <-
-function (period = "LifeToDate", keypair = credentials(),
-    log.requests = getOption('MTurkR.log'), sandbox = getOption('MTurkR.sandbox'),
-    print = getOption('MTurkR.print')) 
-{
+function (period = "LifeToDate", verbose = getOption('MTurkR.verbose'), ...) {
     if(!period %in% c("OneDay", "SevenDays", "ThirtyDays", "LifeToDate")) 
         stop("Period not valid")
     statistics <- c("NumberAssignmentsAvailable", "NumberAssignmentsAccepted", 
@@ -17,17 +14,9 @@ function (period = "LifeToDate", keypair = credentials(),
     z <- setNames(data.frame(matrix(nrow = length(statistics), ncol = 2)),
             c("Statistic", "Value"))
     z[, 1] <- statistics
-    for(i in 1:20) {
-        z[i, 2] <- GetStatistic(statistics[i], period = period, 
-            keypair = keypair, print = FALSE, log.requests = log.requests, 
-            sandbox = sandbox)
-    }
-    for(i in 21:23) {
-        z[i, 2] <- GetStatistic(statistics[i], period = "LifeToDate", 
-            keypair = keypair, print = FALSE, log.requests = log.requests, 
-            sandbox = sandbox)
-    }
-    if(print == TRUE) 
-        print(z)
-    invisible(z)
+    for(i in 1:20)
+        z[i, 2] <- GetStatistic(statistics[i], period = period, ...)
+    for(i in 21:23)
+        z[i, 2] <- GetStatistic(statistics[i], period = "LifeToDate", ...)
+    return(z)
 }
