@@ -1,16 +1,10 @@
 RevokeQualification <-
 RevokeQualifications <-
 revokequal <-
-function (qual, worker, reason = NULL, keypair = credentials(), 
-    print = getOption('MTurkR.print'), browser = getOption('MTurkR.browser'),
-    log.requests = getOption('MTurkR.log'),
-	sandbox = getOption('MTurkR.sandbox'), validation.test = getOption('MTurkR.test')) {
-    if(!is.null(keypair)) {
-        keyid <- keypair[1]
-        secret <- keypair[2]
-    }
-    else
-        stop("No keypair provided or 'credentials' object not stored")
+function (qual, worker, reason = NULL, verbose = getOption('MTurkR.verbose'), ...){
+    # temporary check for `print` argument (remove after v1.0)
+    if('print' %in% names(list(...)) && is.null(verbose))
+        verbose <- list(...)$print
     operation <- "RevokeQualification"
     if(is.factor(qual))
         qual <- as.character(qual)
@@ -24,31 +18,16 @@ function (qual, worker, reason = NULL, keypair = credentials(),
         if(!is.null(reason)) 
             GETparameters <- paste(GETparameters, "&SendNotification=", 
                 curlEscape(reasonbatch), sep = "")
-        auth <- authenticate(operation, secret)
-        if(browser == TRUE) {
-            request <- request(keyid, auth$operation, auth$signature, 
-                auth$timestamp, GETparameters, browser = browser,
-				sandbox = sandbox, validation.test = validation.test)
-			if(validation.test)
-				invisible(request)
-        }
-        else {
-            request <- request(keyid, auth$operation, auth$signature, 
-                auth$timestamp, GETparameters, log.requests = log.requests, 
-                sandbox = sandbox, validation.test = validation.test)
-			if(validation.test)
-				invisible(request)
-            if (request$valid == TRUE) {
-                if (print == TRUE) 
-                    message(i, ": Qualification (", qualbatch, ") for worker ", 
-                    workerbatch, " Revoked")
-            }
-            else if(request$valid == FALSE) {
-                if(print == TRUE) 
-                    warning(i, ": Invalid Request for worker ", workerbatch)
-            }
-            invisible(request)
+        request <- request(operation, GETparameters = GETparameters, ...)
+        if(is.null(request$valid))
+            return(request)
+        if (request$valid & verbose) {
+            message(i, ": Qualification (", qualbatch, ") for worker ", 
+                workerbatch, " Revoked")
         }
+        else if(!request$valid & verbose)
+                warning(i, ": Invalid Request for worker ", workerbatch)
+        return(request)
     }
     Qualifications <- setNames(data.frame(matrix(ncol=4)),
                         c("WorkerId", "QualificationTypeId", "Reason", "Valid"))
@@ -76,8 +55,6 @@ function (qual, worker, reason = NULL, keypair = credentials(),
             }
         }
     }
-    if(print == TRUE) 
-        return(Qualifications)
-    else
-		invisible(Qualifications)
+    Qualifications$Valid <- factor(Qualifications$Valid, levels=c('TRUE','FALSE'))
+    return(Qualifications)
 }
