@@ -2,15 +2,15 @@ SearchHITs <-
 searchhits <-
 function (response.group = NULL, return.all = TRUE, pagenumber = "1", 
     pagesize = "10", sortproperty = "Enumeration", sortdirection = "Ascending", 
-    keypair = credentials(), print = getOption('MTurkR.print'), log.requests = getOption('MTurkR.log'), 
-    sandbox = getOption('MTurkR.sandbox'), return.hit.dataframe = TRUE,
-    return.qual.dataframe = TRUE, validation.test = getOption('MTurkR.test')) {
-    if(!is.null(keypair)) {
-        keyid <- keypair[1]
-        secret <- keypair[2]
-    }
+    return.hit.dataframe = TRUE, return.qual.dataframe = TRUE,
+    verbose = getOption('MTurkR.verbose'), ...) {
+    # temporary check for `print` argument (remove after v1.0)
+    if('print' %in% names(list(...)) && is.null(verbose))
+        verbose <- list(...)$print
+    if('sandbox' %in% names(list(...)))
+        sandbox <- list(...)$sandbox
     else
-        stop("No keypair provided or 'credentials' object not stored")
+        sandbox <- getOption('MTurkR.verbose')
     operation <- "SearchHITs"
     if(!sortproperty %in% c("Title", "Reward", "Expiration", 
         "CreationTime", "Enumeration")) 
@@ -45,37 +45,34 @@ function (response.group = NULL, return.all = TRUE, pagenumber = "1",
         GETiteration <- paste(GETparameters, "&PageNumber=", 
                         pagenumber, "&PageSize=", pagesize, "&SortProperty=", 
                         sortproperty, "&SortDirection=", sortdirection, sep = "")
-        auth <- authenticate(operation, secret)
-        batch <- request(keyid, auth$operation, auth$signature, 
-                        auth$timestamp, GETiteration, log.requests = log.requests, 
-                        sandbox = sandbox, validation.test = validation.test)
-		if(validation.test)
-			invisible(batch)
+        batch <- request(operation, GETparameters = GETiteration, ...)
+        if(is.null(batch$valid))
+            return(batch)
         batch$total <- as.numeric(strsplit(strsplit(batch$xml, 
             "<TotalNumResults>")[[1]][2], "</TotalNumResults>")[[1]][1])
         batch$batch.total <- length(xpathApply(xmlParse(batch$xml), "//HIT"))
         if(return.hit.dataframe == TRUE) {
             if(batch$total > 0) {
-                hitlist <- HITsToDataFrame( xml = batch$xml,
-                                            return.qual.list = return.qual.dataframe,
-                                            sandbox = sandbox)
+                hitlist <- as.data.frame.HITs(xml.parsed = xmlParse(batch$xml),
+                                              return.qual.list = return.qual.dataframe,
+                                              sandbox = sandbox)
                 batch$HITs <- hitlist$HITs
                 if(return.qual.dataframe == TRUE) 
-                  batch$QualificationRequirements <- hitlist$QualificationRequirements
+                    batch$QualificationRequirements <- hitlist$QualificationRequirements
             }
         }
         return(batch)
     }
     request <- batch(pagenumber)
-	if(validation.test)
-		invisible(request)
+    if(is.null(request$valid))
+        return(request)
     runningtotal <- request$batch.total
     if(return.all){
         pagenumber <- 2
         while(request$total > runningtotal) {
             nextbatch <- batch(pagenumber)
-            if(validation.test)
-                invisible(nextbatch)
+            if(is.null(nextbatch$valid))
+                return(nextbatch)
             request$request.id <- c(request$request.id, nextbatch$request.id)
             request$valid <- c(request$valid, nextbatch$valid)
             request$xml.response <- c(request$xml, nextbatch$xml)
@@ -107,7 +104,7 @@ function (response.group = NULL, return.all = TRUE, pagenumber = "1",
             if(length(allQuals)>0){
                 allNames <- character(length=length(allQuals))
                 for(i in 1:length(allQuals))
-                    allNames[i] <- GetQualificationType(allQuals[i], print = print, sandbox = sandbox)$Name
+                    allNames[i] <- GetQualificationType(allQuals[i], verbose = verbose, sandbox = sandbox)$Name
                 for(i in 1:nrow(tmpdf)){
                     if(is.na(tmpdf$Name[i]))
                         tmpdf$Name[i] <- allNames[allQuals==tmpdf$QualificationTypeId[i]]
@@ -118,20 +115,15 @@ function (response.group = NULL, return.all = TRUE, pagenumber = "1",
         if(return.hit.dataframe==TRUE){
             return.list <- list(HITs = request$HITs,
                             QualificationRequirements = request$QualificationRequirements)
-        }
-        else
+        } else
             return.list <- list(QualificationRequirements = request$QualificationRequirements)
-    }
-    else{
+    } else{
         if(return.hit.dataframe == TRUE) 
             return.list <- list(HITs = request$HITs)        
         else
             return.list <- NULL
     }
-    if(print == TRUE) {
+    if(verbose)
         message(runningtotal, " HITs Retrieved")
-        return(return.list)
-    }
-    else
-        invisible(return.list)
+    return(return.list)
 }
