@@ -2,15 +2,11 @@ SearchQualificationTypes <-
 searchquals <-
 function (query = NULL, only.mine = TRUE, only.requestable = FALSE, 
     return.all = FALSE, pagenumber = "1", pagesize = "10", sortproperty = "Name", 
-    sortdirection = "Ascending", keypair = credentials(), print = getOption('MTurkR.print'), 
-    log.requests = getOption('MTurkR.log'), sandbox = getOption('MTurkR.sandbox'),
-    return.qual.dataframe = TRUE, validation.test = getOption('MTurkR.test')) {
-    if(!is.null(keypair)) {
-        keyid <- keypair[1]
-        secret <- keypair[2]
-    }
-    else
-        stop("No keypair provided or 'credentials' object not stored")
+    sortdirection = "Ascending", return.qual.dataframe = TRUE, 
+    verbose = getOption('MTurkR.verbose'), ...) {
+    # temporary check for `print` argument (remove after v1.0)
+    if('print' %in% names(list(...)) && is.null(verbose))
+        verbose <- list(...)$print
     operation <- "SearchQualificationTypes"
     if(!sortproperty %in% c("Name")) 
         stop("'sortproperty' must be 'Name'")
@@ -23,54 +19,48 @@ function (query = NULL, only.mine = TRUE, only.requestable = FALSE,
     GETparameters <- ""
     if(!is.null(query)) 
         GETparameters <- paste(GETparameters, "&Query=", curlEscape(query), sep = "")
-    if(only.mine == TRUE) 
+    if(only.mine) 
         GETparameters <- paste(GETparameters, "&MustBeOwnedByCaller=", "true", sep = "")
-    else if(only.mine == FALSE) 
+    else
         GETparameters <- paste(GETparameters, "&MustBeOwnedByCaller=", "false", sep = "")
-    if(only.requestable == TRUE) 
+    if(only.requestable) 
         GETparameters <- paste(GETparameters, "&MustBeRequestable=", "true", sep = "")
-    else if(only.requestable == FALSE) 
+    else
         GETparameters <- paste(GETparameters, "&MustBeRequestable=", "false", sep = "")
-    batch <- function(operation, keyid, secret, GETparameters, 
-        pagenumber, pagesize, sandbox = sandbox, validation.test = validation.test) {
+    batch <- function(GETparameters, pagenumber, pagesize) {
         GETparameters <- paste(GETparameters, "&PageNumber=", 
             pagenumber, "&PageSize=", pagesize, "&SortProperty=", 
             sortproperty, "&SortDirection=", sortdirection, sep = "")
-        auth <- authenticate(operation, secret)
-        batch <- request(keyid, auth$operation, auth$signature, 
-            auth$timestamp, GETparameters, log.requests = log.requests, 
-            sandbox = sandbox, validation.test = validation.test)
-		if(validation.test)
-			invisible(batch)
+        batch <- request(operation, GETparameters = GETparameters, ...)
+        if(is.null(batch$valid))
+            return(batch)
         batch$total <- as.numeric(strsplit(strsplit(batch$xml, 
-							"<TotalNumResults>")[[1]][2], "</TotalNumResults>")[[1]][1])
+                            "<TotalNumResults>")[[1]][2], "</TotalNumResults>")[[1]][1])
         batch$batch.total <- length(xpathApply(xmlParse(batch$xml), "//QualificationTypeId"))
-        if(return.qual.dataframe == TRUE) {
+        if(return.qual.dataframe) {
             if(batch$total > 0) 
-                batch$quals <- QualificationTypesToDataFrame(xml = batch$xml)
+                batch$quals <- as.data.frame.QualificationTypes(xml.parsed = xmlParse(batch$xml))
         }
         return(batch)
     }
-    request <- batch(operation, keyid, secret, GETparameters, 
-        pagenumber, pagesize, sandbox = sandbox, validation.test = validation.test)
-    if(validation.test)
-		invisible(request)
-	runningtotal <- request$batch.total
-    pagenumber = 2
-    if(return.all == TRUE) {
+    request <- batch(GETparameters, pagenumber, pagesize)
+    if(is.null(request$valid))
+        return(request)
+    runningtotal <- request$batch.total
+    pagenumber <- 2
+    if(return.all) {
         sortproperty <- "Name"
         sortdirection <- "Ascending"
         pagesize <- "100"
         pagenumber <- "1"
         while(request$total > runningtotal) {
-            nextbatch <- batch(operation, keyid, secret, GETparameters, 
-                pagenumber, pagesize, sandbox = sandbox, validation.test = validation.test)
-			if(validation.test)
-				invisible(nextbatch)
+            nextbatch <- batch(GETparameters, pagenumber, pagesize)
+            if(is.null(nextbatch$valid))
+                return(nextbatch)
             request$request.id <- c(request$request.id, nextbatch$request.id)
             request$valid <- c(request$valid, nextbatch$valid)
             request$xml.response <- c(request$xml, nextbatch$xml)
-            if (return.qual.dataframe == TRUE) 
+            if (return.qual.dataframe) 
                 request$quals <- rbind(request$quals, nextbatch$quals)
             request$pages.returned <- pagesize
             runningtotal <- runningtotal + request$batch.total
@@ -78,15 +68,9 @@ function (query = NULL, only.mine = TRUE, only.requestable = FALSE,
         }
     }
     request$batch.total <- NULL
-    if(request$valid[1] == TRUE & print == TRUE) {
+    if(request$valid[1] & verbose)
         message(dim(request$quals)[1], " of ", request$total, " QualificationTypes Retrieved")
-        message(request$quals$QualificationTypeId)
-        invisible(request$quals)
-    }
-    else if(request$valid == FALSE & print == TRUE) {
+    else if(!request$valid[1] & verbose)
         warning("Invalid Request")
-        return(request$quals)
-    }
-    else
-		invisible(request$quals)
+    return(request$quals)
 }
